#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-pandoc-crossref-z-pandoc-crossref-internal
version:              0.3.20
package-name:         pandoc-crossref
lib-name:             pandoc-crossref-internal
id:
    pandoc-crossref-0.3.20-41XNsNlHpvQFTMSh7SPW84-pandoc-crossref-internal

key:
    pandoc-crossref-0.3.20-41XNsNlHpvQFTMSh7SPW84-pandoc-crossref-internal

license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  f1a5deba755a8c59a28f2bacf3ce3e9d
exposed-modules:
    Text.Numeral.Roman Text.Pandoc.CrossRef.References
    Text.Pandoc.CrossRef.References.Blocks
    Text.Pandoc.CrossRef.References.Blocks.CodeBlock
    Text.Pandoc.CrossRef.References.Blocks.Header
    Text.Pandoc.CrossRef.References.Blocks.Math
    Text.Pandoc.CrossRef.References.Blocks.Subfigures
    Text.Pandoc.CrossRef.References.Blocks.Table
    Text.Pandoc.CrossRef.References.Blocks.Util
    Text.Pandoc.CrossRef.References.List
    Text.Pandoc.CrossRef.References.Monad
    Text.Pandoc.CrossRef.References.Refs
    Text.Pandoc.CrossRef.References.Types
    Text.Pandoc.CrossRef.Util.CodeBlockCaptions
    Text.Pandoc.CrossRef.Util.CustomLabels
    Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
    Text.Pandoc.CrossRef.Util.Options
    Text.Pandoc.CrossRef.Util.Settings
    Text.Pandoc.CrossRef.Util.Settings.Gen
    Text.Pandoc.CrossRef.Util.Settings.Template
    Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-crossref-0.3.20
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-crossref-0.3.20
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-crossref-0.3.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:
    HSpandoc-crossref-0.3.20-41XNsNlHpvQFTMSh7SPW84-pandoc-crossref-internal

depends:
    base-4.18.2.1 containers-0.6.7
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG directory-1.3.8.5
    filepath-1.4.300.1 microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-ghc-0.4.15.1-IAH2ejAowXtJjYrGb5ebmG
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    microlens-th-0.4.3.17-1JCZcjTuCbDB2Q9keDntvT mtl-2.3.1
    pandoc-3.10.2-8PCFOS0jtJy3HFs3BZo024
    pandoc-types-1.23.1.2-7r04FP2c39lATDnNYvBdb6
    syb-0.7.4-CWkOfF6Y0mt62kPybHOEB1 template-haskell-2.20.0.0
    text-2.0.2 utility-ht-0.0.17.2-KIIhKEMG0ibEZky8bLfgjA

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-crossref
version:              0.3.20
visibility:           public
id:                   pandoc-crossref-0.3.20-8KBK2IpK8pH1d3O7Dq3jL8
key:                  pandoc-crossref-0.3.20-8KBK2IpK8pH1d3O7Dq3jL8
license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  6df4486d26454e0c2f2aedbc136db371
exposed:              True
exposed-modules:      Text.Pandoc.CrossRef Text.Pandoc.CrossRef.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-crossref-0.3.20
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-crossref-0.3.20
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-crossref-0.3.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:         HSpandoc-crossref-0.3.20-8KBK2IpK8pH1d3O7Dq3jL8
depends:
    base-4.18.2.1 mtl-2.3.1 pandoc-3.10.2-8PCFOS0jtJy3HFs3BZo024
    pandoc-crossref-0.3.20-41XNsNlHpvQFTMSh7SPW84-pandoc-crossref-internal
    pandoc-types-1.23.1.2-7r04FP2c39lATDnNYvBdb6 text-2.0.2

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

